/*
 *  plex86: run multiple x86 operating systems concurrently
 *  Copyright (C) 1999-2001 Kevin P. Lawton
 *
 *  iodev-protos.h:  IO devices, function protypes
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */



// xxx Put these in appropriate files.
void initIODevices(vm_t *vm);
void picInit(vm_t *vm);
void pitInit(vm_t *vm);
#if 0
unsigned picTriggerIRQ(vm_t *vm, unsigned irq);
unsigned picUntriggerIRQ(vm_t *vm, unsigned irq);
#endif
unsigned picRaiseIRQ(vm_t *vm, unsigned irq);
unsigned picLowerIRQ(vm_t *vm, unsigned irq);
void miscIOInit(vm_t *vm);
